@@ -15,9 +15,8 @@ const _ = Gettext.gettext;
 const WORKSPACE_SCHEMA = 'org.gnome.desktop.wm.preferences';
 const WORKSPACE_KEY = 'workspace-names';
 
-let WindowPreview = GObject.registerClass({
-    GTypeName: 'WorkspaceIndicatorWindowPreview',
-}, class WindowPreview extends St.Button {
+let WindowPreview = GObject.registerClass(
+class WindowPreview extends St.Button {
     _init(window) {
         super._init({
             style_class: 'workspace-indicator-window-preview',
@@ -84,6 +83,7 @@ let WindowPreview = GObject.registerClass({
     _relayout() {
         let monitor = Main.layoutManager.findIndexForActor(this);
         this.visible = monitor === this._window.get_monitor() &&
+            this._window.window_type !== Meta.WindowType.DESKTOP &&
             this._window.showing_on_its_workspace();
 
         if (!this.visible)
@@ -103,9 +103,8 @@ let WindowPreview = GObject.registerClass({
     }
 });
 
-let WorkspaceThumbnail = GObject.registerClass({
-    GTypeName: 'WorkspaceIndicatorWorkspaceThumbnail',
-}, class WorkspaceThumbnail extends St.Button {
+let WorkspaceThumbnail = GObject.registerClass(
+class WorkspaceThumbnail extends St.Button {
     _init(index) {
         super._init({
             style_class: 'workspace',
